@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Mathias Hasselmann
+ *  Copyright © 2005 Mathias Hasselmann
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-java-console-extension.c,v 1.1.4.1 2006/09/06 20:12:15 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -24,7 +24,7 @@
 #include "java-console.h"
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 #include <glib/gi18n-lib.h>
 #include <gmodule.h>
