@@ -15,18 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: java-console.cpp 1728 2008-05-18 21:51:17Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-
-#ifdef XPCOM_GLUE
-#include <nsXPCOMGlue.h>
-#include <gtkmozembed_glue.cpp>
-#endif
-
 #include <nsCOMPtr.h>
 #include <nsIJVMManager.h>
 #include <nsServiceManagerUtils.h>
@@ -54,25 +48,3 @@ java_console_show (void)
 
 	jvmmgr->ShowJavaConsole ();
 }
-
-gboolean
-mozilla_glue_startup (void)
-{
-#ifdef XPCOM_GLUE
-	static const GREVersionRange greVersion = {
-	  "1.9a", PR_TRUE,
-	  "2", PR_TRUE
-	};
-	char xpcomLocation[4096];
-
-	if (NS_FAILED (GRE_GetGREPathWithProperties(&greVersion, 1, nsnull, 0, xpcomLocation, sizeof (xpcomLocation))) ||
-	    NS_FAILED (XPCOMGlueStartup (xpcomLocation)) ||
-	    NS_FAILED (GTKEmbedGlueStartup ()) ||
-	    NS_FAILED (GTKEmbedGlueStartupInternal()))
-                return FALSE;
-
-        return TRUE;
-#else
-        return TRUE;
-#endif /* XPCOM_GLUE */
-}
